# afplay-py

A python wrapper around the macOS tool `afplay` (audio-file player).

## Installation

From pip:

```shell
pip install afplay-py
```

From source (from the root project directory):

```shell
pip install .
```

## Quick Usage

```python
from afplay import afplay

afplay("path/to/file.mp3")
```
